==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-date/xl-react-widget-date.js <==
import React, {Component} from 'react';
import R from 'ramda';
import PropTypes from 'prop-types';
import moment from 'moment';
import 'react-datepicker/dist/react-datepicker.css';
import {getModelValue, isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import {localeMessages} from '../../services/locale-service';
import {XlReactWidgetContainerProps} from '../xl-react-widget-props';
import {
    computeInitialState,
    computeNextState,
    computeNextPropsState,
    getValidators
} from '../../services/component-service';
import {isDateInRange, genericDateFormat} from '../../utils/date-utils';
import {ERROR} from '../../utils/ci-utils';
import {XlReactWidgetDateComponent} from './xl-react-widget-date-component';

export class XlReactWidgetDate extends Component {
    static propTypes = {
        dateFormat: PropTypes.string,
        invalidDateFormatErrorMessage: PropTypes.string,
        maxDate: PropTypes.object,
        messageHandler: PropTypes.func,
        metadata: PropTypes.object,
        minDate: PropTypes.object,
        model: PropTypes.object,
        showParentMessages: PropTypes.bool,
        ...XlReactWidgetContainerProps
    };

    static defaultProps = {
        dateFormat: genericDateFormat,
        metadata: {},
        validators: []
    };

    constructor(props) {
        super(props);
        this.state = {};
    }

    componentWillMount() {
        const model = getModelValue(this.props, 'model', new Date());
        computeInitialState(this, this.props, this.getDateValidators(this.props), model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, this.getDateValidators(nextProps));
    }

    onChange = (date) => {
        computeNextState(this, this.props, this.getDateValidators(this.props), this.getMomentDate(date));
    };

    onBlur = (event) => {
        const selectedDate = R.pathOr(false, ['target', 'value'], event);
        if (selectedDate) {
            computeNextState(this, this.props, this.getDateValidators(this.props), this.getMomentDate(selectedDate));
        }
    };

    getMomentDate = (date) => this.toMoment(date).toDate();

    toMoment = (value) => moment(value, this.props.dateFormat, true);

    api = {
        focus: () => this.inputField.focus(),
        resetPristinity: (config) => resetPristinity(this, this.props, config)
    };

    assignRef = (dateWidget) => {
        this.inputField = dateWidget ? dateWidget.input : undefined;
    };

    getInvalidDateValidator = (model) => {
        const message = {
            show: true,
            text: this.props.invalidDateFormatErrorMessage || localeMessages.invalidDateExampleMessage,
            type: ERROR
        };

        const condition = model && !this.toMoment(model).isValid();
        return {condition, message};
    };

    getDateValidators = (props) => {
        const {maxDate, minDate} = this.props;
        return getValidators(props, [this.getInvalidDateValidator, (model) => ({
            condition: !isDateInRange({checkedDate: model, maxDate, minDate}),
            message: {
                show: true,
                text: localeMessages.dateIsNotAllowed,
                type: ERROR
            }
        })]);
    };

    render() {
        const {
            dateFormat, displayMode, maxDate, minDate, onValidityChange,
            metadata: {description, label, placeholder}
        } = this.props;
        const {message, model, valid} = this.state;
        const disabled = isComponentDisabled(this.props);

        return <XlReactWidgetDateComponent {...({
            assignRef: this.assignRef,
            dateFormat,
            description,
            disabled,
            displayMode,
            handleModelChange: this.onChange,
            handleOnBlur: this.onBlur,
            label,
            maxDate: maxDate && moment(maxDate).toDate(),
            message,
            minDate: minDate && moment(minDate).toDate(),
            model,
            onValidityChange,
            placeholderText: placeholder,
            valid
        })}
        />;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-date/xl-react-widget-date.js <==
import React, {Component} from 'react';
import R from 'ramda';
import PropTypes from 'prop-types';
import moment from 'moment';
import 'react-datepicker/dist/react-datepicker.css';
import {getModelValue, isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import {localeMessages} from '../../services/locale-service';
import {XlReactWidgetContainerProps} from '../xl-react-widget-props';
import {
    computeInitialState,
    computeNextState,
    computeNextPropsState,
    getValidators
} from '../../services/component-service';
import {isDateInRange, genericDateFormat} from '../../utils/date-utils';
import {ERROR} from '../../utils/ci-utils';
import {XlReactWidgetDateComponent} from './xl-react-widget-date-component';

export class XlReactWidgetDate extends Component {
    static propTypes = {
        dateFormat: PropTypes.string,
        invalidDateFormatErrorMessage: PropTypes.string,
        maxDate: PropTypes.object,
        messageHandler: PropTypes.func,
        metadata: PropTypes.object,
        minDate: PropTypes.object,
        model: PropTypes.object,
        showParentMessages: PropTypes.bool,
        ...XlReactWidgetContainerProps
    };

    static defaultProps = {
        dateFormat: genericDateFormat,
        metadata: {},
        validators: []
    };

    constructor(props) {
        super(props);
        this.state = {};
    }

    componentWillMount() {
        const model = getModelValue(this.props, 'model', new Date());
        computeInitialState(this, this.props, this.getDateValidators(this.props), model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, this.getDateValidators(nextProps));
    }

    onChange = (date) => {
        computeNextState(this, this.props, this.getDateValidators(this.props), this.getMomentDate(date));
    };

    onBlur = (event) => {
        const selectedDate = R.pathOr(false, ['target', 'value'], event);
        if (selectedDate) {
            computeNextState(this, this.props, this.getDateValidators(this.props), this.getMomentDate(selectedDate));
        }
    };

    getMomentDate = (date) => this.toMoment(date).toDate();

    toMoment = (value) => moment(value, this.props.dateFormat, true);

    api = {
        focus: () => this.inputField.focus(),
        resetPristinity: (config) => resetPristinity(this, this.props, config)
    };

    assignRef = (dateWidget) => {
        this.inputField = dateWidget ? dateWidget.input : undefined;
    };

    getInvalidDateValidator = (model) => {
        const message = {
            show: true,
            text: this.props.invalidDateFormatErrorMessage || localeMessages.invalidDateExampleMessage,
            type: ERROR
        };

        const condition = model && !this.toMoment(model).isValid();
        return {condition, message};
    };

    getDateValidators = (props) => {
        const {maxDate, minDate} = this.props;
        return getValidators(props, [this.getInvalidDateValidator, (model) => ({
            condition: !isDateInRange({checkedDate: model, maxDate, minDate}),
            message: {
                show: true,
                text: localeMessages.dateIsNotAllowed,
                type: ERROR
            }
        })]);
    };

    render() {
        const {
            className, dateFormat, displayMode, maxDate, minDate, onValidityChange,
            metadata: {description, label, placeholder}
        } = this.props;
        const {message, model, valid} = this.state;
        const disabled = isComponentDisabled(this.props);

        return <XlReactWidgetDateComponent {...({
            assignRef: this.assignRef,
            className,
            dateFormat,
            description,
            disabled,
            displayMode,
            handleModelChange: this.onChange,
            handleOnBlur: this.onBlur,
            label,
            maxDate: maxDate && moment(maxDate).toDate(),
            message,
            minDate: minDate && moment(minDate).toDate(),
            model,
            onValidityChange,
            placeholderText: placeholder,
            valid
        })}
        />;
    }
}
